.. mdinclude:: ../README.md

.. toctree::
   :hidden:
   :titlesonly:

   Overview <self>
   installation
   usage

.. toctree::
   :caption: Advanced Usage
   :hidden:

   API Reference <api/mit_d3m>

.. toctree::
   :caption: Development Notes
   :hidden:

   contributing
   authors
   history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
